@@ -88,9 +88,8 @@ static int osinfo_db_export_create_reg(GFile *file,
 
     ret = 0;
  cleanup:
-    if (err)
-        g_error_free(err);
-    g_object_unref(is);
+    g_clear_error(&err);
+    g_clear_object(&is);
     g_free(buf);
     return ret;
 }
@@ -104,6 +103,8 @@ static int osinfo_db_export_create_dir(const gchar *prefix,
                                        gboolean verbose)
 {
     GFileEnumerator *children;
+    GFileInfo *childinfo = NULL;
+    GFile *child = NULL;
     GError *err = NULL;
     int ret = -1;
 
@@ -121,8 +122,7 @@ static int osinfo_db_export_create_dir(const gchar *prefix,
     }
 
     while (1) {
-        GFileInfo *childinfo = NULL;
-        GFile *child = NULL;
+        int export_create_ret;
 
         childinfo = g_file_enumerator_next_file(children, NULL, &err);
         if (!childinfo) {
@@ -137,20 +137,17 @@ static int osinfo_db_export_create_dir(const gchar *prefix,
 
         child = g_file_enumerator_get_child(children, childinfo);
 
-        if (osinfo_db_export_create_file(prefix, child, childinfo, base, target, arc, verbose) < 0) {
-            g_object_unref(child);
-            g_object_unref(childinfo);
-            goto cleanup;
-        }
+        export_create_ret = osinfo_db_export_create_file(prefix, child, childinfo, base, target, arc, verbose);
+        g_clear_object(&child);
+        g_clear_object(&childinfo);
 
-        g_object_unref(child);
-        g_object_unref(childinfo);
+        if (export_create_ret < 0)
+            goto cleanup;
     }
 
     ret = 0;
  cleanup:
-    if (err)
-        g_error_free(err);
+    g_clear_error(&err);
     return ret;
 }
 
@@ -285,10 +282,8 @@ static int osinfo_db_export_create_file(const gchar *prefix,
     g_free(abspath);
     g_free(relpath);
     g_free(entpath);
-    if (info)
-        g_object_unref(info);
-    if (err)
-        g_error_free(err);
+    g_clear_object(&info);
+    g_clear_error(&err);
     return ret;
 }
 
@@ -392,8 +387,7 @@ static int osinfo_db_export_create_license(const gchar *prefix,
     ret = 0;
  cleanup:
     archive_entry_free(entry);
-    if (err)
-        g_error_free(err);
+    g_clear_error(&err);
     return ret;
 }
 
@@ -407,7 +401,6 @@ static int osinfo_db_export_create(const gchar *prefix,
     struct archive *arc;
     int ret = -1;
     int r;
-    GError *err = NULL;
 
     arc = archive_write_new();
 
@@ -445,8 +438,6 @@ static int osinfo_db_export_create(const gchar *prefix,
     ret = 0;
  cleanup:
     archive_write_free(arc);
-    if (err)
-        g_error_free(err);
     return ret;
 }
 
@@ -489,17 +480,17 @@ gint main(gint argc, gchar **argv)
       { "verbose", 'v', 0, G_OPTION_ARG_NONE, (void*)&verbose,
         N_("Verbose progress information"), NULL, },
       { "user", 0, 0, G_OPTION_ARG_NONE, (void *)&user,
-        N_("Install into user directory"), NULL, },
+        N_("Export the osinfo-db user directory"), NULL, },
       { "local", 0, 0, G_OPTION_ARG_NONE, (void *)&local,
-        N_("Install into local directory"), NULL, },
+        N_("Export the osinfo-db local directory"), NULL, },
       { "system", 0, 0, G_OPTION_ARG_NONE, (void *)&system,
-        N_("Install into system directory"), NULL, },
+        N_("Export the osinfo-db system directory"), NULL, },
       { "dir", 0, 0, G_OPTION_ARG_STRING, (void *)&custom,
-        N_("Import into custom directory"), NULL, },
+        N_("Export an osinfo-db custom directory"), NULL, },
       { "version", 0, 0, G_OPTION_ARG_STRING, (void *)&version,
         N_("Set version number of archive"), NULL, },
       { "root", 0, 0, G_OPTION_ARG_STRING, &root,
-        N_("Installation root directory"), NULL, },
+        N_("Export the osinfo-db root directory"), NULL, },
       { "license", 0, 0, G_OPTION_ARG_STRING, &license,
         N_("License file"), NULL, },
       { NULL, 0, 0, 0, NULL, NULL, NULL },
@@ -563,9 +554,7 @@ gint main(gint argc, gchar **argv)
     g_free(archive);
     g_free(autoversion);
     g_free(prefix);
-    if (dir) {
-        g_object_unref(dir);
-    }
+    g_clear_object(&dir);
     g_clear_error(&error);
     g_option_context_free(context);
 
